/* Sistemas Integrados TECNISA

Nome: 033N_SUPTRGS_LOG_SUP_AJUSTEPRFORNFIL.SQL

Descrio:
   Trigger para gravar o registro de alteraes na tabela de Percentual de Ajuste de Preos dos Fornecedores para as Filiais.

Criao:
   21/01/2010 - Marcelo Alex.
*/

/* Tabela AJUSTEPRFORNFIL: Percentual de Ajuste de Preos dos Fornecedores para as Filiais. */
/* Descrio: A trigger insere registros na tabela LOGOPERA a partir de alteraes na tabela AJUSTEPRFORNFIL*/
/* Objetivo:  Gerar um log que vai registrar as alteraes na tabela Percentual de Ajuste de Preos dos Fornecedores para as Filiais,
              utilizando a tabela Geral de Logs de Operaes*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'LOG_SUP_AJUSTEPRFORNFIL' AND
                 TYPE = 'TR' 		                   AND
	              U.UID = O.UID                      AND
	              U.NAME = USER)
DROP TRIGGER LOG_SUP_AJUSTEPRFORNFIL
GO


CREATE  TRIGGER LOG_SUP_AJUSTEPRFORNFIL
ON AJUSTEPRFORNFIL
FOR INSERT, UPDATE, DELETE
AS
   DECLARE  @V_USUARIO   VARCHAR(40);
   DECLARE  @V_TIPO      VARCHAR(1);
   DECLARE  @V_ITPESQ    VARCHAR(40);
   DECLARE  @V_DESC      VARCHAR(300);
   DECLARE  @V_DTOPER    DATETIME;

/*VARIVEIS DO CURSOR C_CURSOR*/

   DECLARE @V_ID_COMANDO        VARCHAR(1) ;

   DECLARE @V_OLD_CDFILIAL        VARCHAR(4);
   DECLARE @V_OLD_CDFORNECED      VARCHAR(21);
   DECLARE @V_OLD_DTINIAJPRFORFIL DATETIME;
   DECLARE @V_OLD_DTFINAJPRFORFIL DATETIME;
   DECLARE @V_OLD_VRPERAJFORNFIL DOUBLE PRECISION;
   DECLARE @V_OLD_IDCONSPERPIAJPR DOUBLE PRECISION;

   DECLARE @V_NEW_CDFILIAL        VARCHAR(4);
   DECLARE @V_NEW_CDFORNECED      VARCHAR(21);
   DECLARE @V_NEW_DTINIAJPRFORFIL DATETIME;
   DECLARE @V_NEW_DTFINAJPRFORFIL DATETIME;
   DECLARE @V_NEW_VRPERAJFORNFIL DOUBLE PRECISION;
   DECLARE @V_NEW_IDCONSPERPIAJPR DOUBLE PRECISION;
BEGIN

   SET @V_DESC     = '';
   SET @V_TIPO     = '0';

   EXEC NMUSUARIO @V_USUARIO;
   SET @V_USUARIO = ISNULL(@V_USUARIO, ' ');

   DECLARE C_CURSOR CURSOR FOR

      SELECT
         'U' IDCOMANDO,
         INSERTED.CDFORNECED,
         INSERTED.CDFILIAL,
         INSERTED.DTINIAJPRFORFIL,
         INSERTED.DTFINAJPRFORFIL,
         INSERTED.VRPERAJFORNFIL,
         INSERTED.IDCONSPERPIAJPR,
         DELETED.CDFORNECED,
         DELETED.CDFILIAL,
         DELETED.DTINIAJPRFORFIL,
         DELETED.DTFINAJPRFORFIL,
         DELETED.VRPERAJFORNFIL,
         DELETED.IDCONSPERPIAJPR
      FROM
         INSERTED,
         DELETED
      WHERE INSERTED.CDFILIAL        = DELETED.CDFILIAL
        AND INSERTED.CDFORNECED      = DELETED.CDFORNECED
        AND INSERTED.DTINIAJPRFORFIL = DELETED.DTINIAJPRFORFIL

      UNION ALL

      SELECT
         'I' IDCOMANDO,
         INSERTED.CDFORNECED,
         INSERTED.CDFILIAL,
         INSERTED.DTINIAJPRFORFIL,
         INSERTED.DTFINAJPRFORFIL,
         INSERTED.VRPERAJFORNFIL,
         INSERTED.IDCONSPERPIAJPR,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL
      FROM
         INSERTED
      WHERE
         CDFORNECED+CDFILIAL+DTINIAJPRFORFIL  NOT IN (SELECT CDFORNECED+CDFILIAL+DTINIAJPRFORFIL  FROM DELETED)

      UNION ALL

      SELECT
         'D' IDCOMANDO,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         DELETED.CDFORNECED,
         DELETED.CDFILIAL,
         DELETED.DTINIAJPRFORFIL,
         DELETED.DTFINAJPRFORFIL,
         DELETED.VRPERAJFORNFIL,
         DELETED.IDCONSPERPIAJPR
      FROM
         DELETED
      WHERE
         CDFORNECED+CDFILIAL+DTINIAJPRFORFIL  NOT IN (SELECT CDFORNECED+CDFILIAL+DTINIAJPRFORFIL  FROM INSERTED)

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                 @V_NEW_CDFILIAL,
                                 @V_NEW_CDFORNECED,
                                 @V_NEW_DTINIAJPRFORFIL,
                                 @V_NEW_DTFINAJPRFORFIL,
                                 @V_NEW_VRPERAJFORNFIL,
                                 @V_NEW_IDCONSPERPIAJPR,
                                 @V_OLD_CDFILIAL,
                                 @V_OLD_CDFORNECED,
                                 @V_OLD_DTINIAJPRFORFIL,
                                 @V_OLD_DTFINAJPRFORFIL,
                                 @V_OLD_VRPERAJFORNFIL,
                                 @V_OLD_IDCONSPERPIAJPR;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      IF NOT @V_USUARIO IS NULL BEGIN
         IF @V_ID_COMANDO= 'D' /*DELETING*/ BEGIN
            SET @V_TIPO = '3';

            IF @V_OLD_CDFORNECED IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Fornec=' + @V_OLD_CDFORNECED;
            END;

            IF @V_OLD_CDFILIAL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Filial=' + @V_OLD_CDFILIAL;
            END;


            IF @V_OLD_DTINIAJPRFORFIL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Inicial=' + CONVERT(VARCHAR, @V_OLD_DTINIAJPRFORFIL);
            END;

            IF @V_OLD_DTFINAJPRFORFIL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'Final=' + CONVERT(VARCHAR, @V_OLD_DTFINAJPRFORFIL);
            END;

            IF @V_OLD_VRPERAJFORNFIL IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + '%=' + CONVERT(VARCHAR, @V_OLD_VRPERAJFORNFIL);
            END;

            IF @V_OLD_IDCONSPERPIAJPR IS NOT NULL BEGIN
               SET @V_DESC = @V_DESC + 'PI/DSV=' + @V_OLD_IDCONSPERPIAJPR;
            END;
            SET @V_ITPESQ = @V_OLD_CDFORNECED + @V_OLD_CDFILIAL + CONVERT(VARCHAR, @V_OLD_DTINIAJPRFORFIL);
         END
         ELSE BEGIN
            IF @V_ID_COMANDO= 'U' /*UPDATING*/ BEGIN
               SET @V_ITPESQ = @V_NEW_CDFORNECED + @V_NEW_CDFILIAL + CONVERT(VARCHAR, @V_NEW_DTINIAJPRFORFIL);
               IF (ISNULL(@V_OLD_DTFINAJPRFORFIL, CONVERT(DATETIME, GETDATE(), 103)) <> ISNULL(@V_NEW_DTFINAJPRFORFIL, CONVERT(DATETIME, GETDATE(), 103))) OR
                  (ISNULL(@V_OLD_VRPERAJFORNFIL, 0) <> ISNULL(@V_NEW_VRPERAJFORNFIL, 0))                                                                 OR
                  (@V_OLD_IDCONSPERPIAJPR <> @V_NEW_IDCONSPERPIAJPR)                                                                                       BEGIN
                  SET  @V_TIPO   = '2';
               END;
            END
            ELSE BEGIN
               SET @V_TIPO   = '1';
               SET @V_ITPESQ = @V_NEW_CDFORNECED + @V_NEW_CDFILIAL + CONVERT(VARCHAR, @V_NEW_DTINIAJPRFORFIL);
            END;
         END;


         IF (@V_TIPO <> '0')  BEGIN
            IF NOT @V_DESC IS NULL BEGIN
               SET  @V_DTOPER = GETDATE();
               INSERT INTO LOGOPERA
                          (NMTABELA, DTOPERACAO, NMRESPOPER,
                           IDTIPOOPER, CDPESQITEM, DSOPERACAO, CDFILLOGOPER)
                      VALUES
                          ('AJUSTEPRFORNFIL', @V_DTOPER, @V_USUARIO,
                           @V_TIPO, @V_ITPESQ, @V_DESC, @V_NEW_CDFILIAL);
            END;
         END;
      END;
      FETCH NEXT FROM C_CURSOR INTO @V_ID_COMANDO,
                                    @V_NEW_CDFILIAL,
                                    @V_NEW_CDFORNECED,
                                    @V_NEW_DTINIAJPRFORFIL,
                                    @V_NEW_DTFINAJPRFORFIL,
                                    @V_NEW_VRPERAJFORNFIL,
                                    @V_NEW_IDCONSPERPIAJPR,
                                    @V_OLD_CDFILIAL,
                                    @V_OLD_CDFORNECED,
                                    @V_OLD_DTINIAJPRFORFIL,
                                    @V_OLD_DTFINAJPRFORFIL,
                                    @V_OLD_VRPERAJFORNFIL,
                                    @V_OLD_IDCONSPERPIAJPR;

   END;
   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;
END;
 GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_SUP_AJUSTEPRFORNFIL','5.09.000';
GO

